@@ -2,7 +2,7 @@
 Data persistance and pipelining tools
 """
 
-from apipe._cached import CachedResultItem, cached, clear_cache  # noqa: F401
+from apipe._cached import CachedResultItem, cached, clear_cache, eager_cached, load  # noqa: F401
 from apipe._dask import (  # noqa: F401
     DelayedParameter,
     DelayedParameters,
